@@ -20,36 +20,36 @@
 #include <util/darray.h>
 
 #ifdef _WIN32
-#  include <ws2tcpip.h>
-#  include <winsock2.h>
-#  include <ws2ipdef.h>
-#  include <iphlpapi.h>
+#include <ws2tcpip.h>
+#include <winsock2.h>
+#include <ws2ipdef.h>
+#include <iphlpapi.h>
 #else
 
-#  ifdef __linux__
-#    include <linux/if_link.h>
-#  elif __FreeBSD__
-#    include <netinet/in.h>
-#    ifndef _GNU_SOURCE
-#      define _GNU_SOURCE
-#      define __NET_IF_GNU_SOURCE__
-#    endif //_GNU_SOURCE
-#  endif //__FreeBSD__
+#ifdef __linux__
+#include <linux/if_link.h>
+#elif __FreeBSD__
+#include <netinet/in.h>
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#define __NET_IF_GNU_SOURCE__
+#endif //_GNU_SOURCE
+#endif //__FreeBSD__
 
-#  include <ifaddrs.h>
-#  include <netdb.h>
-#  include <stdio.h>
-#  include <stdlib.h>
-#  include <unistd.h>
-#  include <arpa/inet.h>
-#  include <sys/socket.h>
+#include <ifaddrs.h>
+#include <netdb.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <arpa/inet.h>
+#include <sys/socket.h>
 
-#  ifdef __FreeBSD__
-#    ifdef ___NET_IF_GNU_SOURCE__
-#      undef ___NET_IF_GNU_SOURCE__
-#      undef _GNU_SOURCE
-#    endif
-#  endif
+#ifdef __FreeBSD__
+#ifdef ___NET_IF_GNU_SOURCE__
+#undef ___NET_IF_GNU_SOURCE__
+#undef _GNU_SOURCE
+#endif
+#endif
 
 #endif
 
@@ -71,7 +71,7 @@ static inline void netif_saddr_data_free(struct netif_saddr_data *data)
 	da_free(data->addrs);
 }
 
-extern bool netif_str_to_addr(struct sockaddr_storage *out, int *addr_len,
-		const char *addr);
+extern bool netif_str_to_addr(struct sockaddr_storage *out, int *addr_len, const char *addr);
+extern bool netif_addr_to_str(struct sockaddr_storage *in, char *addr, int addr_len);
 extern void netif_get_addrs(struct netif_saddr_data *ifaddrs);
 extern void netif_log_saddrs(struct netif_saddr_data *sd);
