@@ -1,5 +1,5 @@
 /******************************************************************************
-    Copyright (C) 2014 by Hugh Bailey <obs.jim@gmail.com>
+    Copyright (C) 2023 by Lain Bailey <lain@obsproject.com>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,11 +22,6 @@
 #include <obs-hevc.h>
 #endif
 
-#if LIBAVCODEC_VERSION_INT > AV_VERSION_INT(58, 4, 100)
-#define USE_NEW_HARDWARE_CODEC_METHOD
-#endif
-
-#ifdef USE_NEW_HARDWARE_CODEC_METHOD
 enum AVHWDeviceType hw_priority[] = {
 	AV_HWDEVICE_TYPE_D3D11VA,
 	AV_HWDEVICE_TYPE_DXVA2,
@@ -42,8 +37,7 @@ static bool has_hw_type(const AVCodec *c, enum AVHWDeviceType type)
 			break;
 		}
 
-		if (config->methods & AV_CODEC_HW_CONFIG_METHOD_HW_DEVICE_CTX &&
-		    config->device_type == type)
+		if (config->methods & AV_CODEC_HW_CONFIG_METHOD_HW_DEVICE_CTX && config->device_type == type)
 			return true;
 	}
 
@@ -57,8 +51,7 @@ static void init_hw_decoder(struct ffmpeg_decode *d)
 
 	while (*priority != AV_HWDEVICE_TYPE_NONE) {
 		if (has_hw_type(d->codec, *priority)) {
-			int ret = av_hwdevice_ctx_create(&hw_ctx, *priority,
-							 NULL, NULL, 0);
+			int ret = av_hwdevice_ctx_create(&hw_ctx, *priority, NULL, NULL, 0);
 			if (ret == 0)
 				break;
 		}
@@ -72,16 +65,11 @@ static void init_hw_decoder(struct ffmpeg_decode *d)
 		d->hw = true;
 	}
 }
-#endif
 
-int ffmpeg_decode_init(struct ffmpeg_decode *decode, enum AVCodecID id,
-		       bool use_hw)
+int ffmpeg_decode_init(struct ffmpeg_decode *decode, enum AVCodecID id, bool use_hw)
 {
 	int ret;
 
-#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58, 9, 100)
-	avcodec_register_all();
-#endif
 	memset(decode, 0, sizeof(*decode));
 
 	decode->codec = avcodec_find_decoder(id);
@@ -92,12 +80,8 @@ int ffmpeg_decode_init(struct ffmpeg_decode *decode, enum AVCodecID id,
 
 	decode->decoder->thread_count = 0;
 
-#ifdef USE_NEW_HARDWARE_CODEC_METHOD
 	if (use_hw)
 		init_hw_decoder(decode);
-#else
-	(void)use_hw;
-#endif
 
 	ret = avcodec_open2(decode->decoder, decode->codec, NULL);
 	if (ret < 0) {
@@ -105,9 +89,6 @@ int ffmpeg_decode_init(struct ffmpeg_decode *decode, enum AVCodecID id,
 		return ret;
 	}
 
-	if (decode->codec->capabilities & CODEC_CAP_TRUNC)
-		decode->decoder->flags |= CODEC_FLAG_TRUNC;
-
 	return 0;
 }
 
@@ -136,6 +117,8 @@ static inline enum video_format convert_pixel_format(int f)
 	switch (f) {
 	case AV_PIX_FMT_NONE:
 		return VIDEO_FORMAT_NONE;
+	case AV_PIX_FMT_GRAY8:
+		return VIDEO_FORMAT_Y800;
 	case AV_PIX_FMT_YUV420P:
 	case AV_PIX_FMT_YUVJ420P:
 		return VIDEO_FORMAT_I420;
@@ -215,14 +198,12 @@ static inline enum speaker_layout convert_speaker_layout(uint8_t channels)
 	}
 }
 
-static inline void copy_data(struct ffmpeg_decode *decode, uint8_t *data,
-			     size_t size)
+static inline void copy_data(struct ffmpeg_decode *decode, uint8_t *data, size_t size)
 {
 	size_t new_size = size + INPUT_BUFFER_PADDING_SIZE;
 
 	if (decode->packet_size < new_size) {
-		decode->packet_buffer =
-			brealloc(decode->packet_buffer, new_size);
+		decode->packet_buffer = brealloc(decode->packet_buffer, new_size);
 		decode->packet_size = new_size;
 	}
 
@@ -230,8 +211,7 @@ static inline void copy_data(struct ffmpeg_decode *decode, uint8_t *data,
 	memcpy(decode->packet_buffer, data, size);
 }
 
-bool ffmpeg_decode_audio(struct ffmpeg_decode *decode, uint8_t *data,
-			 size_t size, struct obs_source_audio *audio,
+bool ffmpeg_decode_audio(struct ffmpeg_decode *decode, uint8_t *data, size_t size, struct obs_source_audio *audio,
 			 bool *got_output)
 {
 	int got_frame = false;
@@ -274,8 +254,7 @@ bool ffmpeg_decode_audio(struct ffmpeg_decode *decode, uint8_t *data,
 
 	audio->samples_per_sec = decode->frame->sample_rate;
 	audio->format = convert_sample_format(decode->frame->format);
-	audio->speakers =
-		convert_speaker_layout((uint8_t)decode->decoder->channels);
+	audio->speakers = convert_speaker_layout((uint8_t)decode->decoder->ch_layout.nb_channels);
 
 	audio->frames = decode->frame->nb_samples;
 
@@ -286,35 +265,29 @@ bool ffmpeg_decode_audio(struct ffmpeg_decode *decode, uint8_t *data,
 	return true;
 }
 
-static enum video_colorspace
-convert_color_space(enum AVColorSpace s, enum AVColorTransferCharacteristic trc,
-		    enum AVColorPrimaries color_primaries)
+static enum video_colorspace convert_color_space(enum AVColorSpace s, enum AVColorTransferCharacteristic trc,
+						 enum AVColorPrimaries color_primaries)
 {
 	switch (s) {
 	case AVCOL_SPC_BT709:
-		return (trc == AVCOL_TRC_IEC61966_2_1) ? VIDEO_CS_SRGB
-						       : VIDEO_CS_709;
+		return (trc == AVCOL_TRC_IEC61966_2_1) ? VIDEO_CS_SRGB : VIDEO_CS_709;
 	case AVCOL_SPC_FCC:
 	case AVCOL_SPC_BT470BG:
 	case AVCOL_SPC_SMPTE170M:
 	case AVCOL_SPC_SMPTE240M:
 		return VIDEO_CS_601;
 	case AVCOL_SPC_BT2020_NCL:
-		return (trc == AVCOL_TRC_ARIB_STD_B67) ? VIDEO_CS_2100_HLG
-						       : VIDEO_CS_2100_PQ;
+		return (trc == AVCOL_TRC_ARIB_STD_B67) ? VIDEO_CS_2100_HLG : VIDEO_CS_2100_PQ;
 	default:
 		return (color_primaries == AVCOL_PRI_BT2020)
-			       ? ((trc == AVCOL_TRC_ARIB_STD_B67)
-					  ? VIDEO_CS_2100_HLG
-					  : VIDEO_CS_2100_PQ)
+			       ? ((trc == AVCOL_TRC_ARIB_STD_B67) ? VIDEO_CS_2100_HLG : VIDEO_CS_2100_PQ)
 			       : VIDEO_CS_DEFAULT;
 	}
 }
 
-bool ffmpeg_decode_video(struct ffmpeg_decode *decode, uint8_t *data,
-			 size_t size, long long *ts,
-			 enum video_range_type range,
-			 struct obs_source_frame2 *frame, bool *got_output)
+bool ffmpeg_decode_video(struct ffmpeg_decode *decode, uint8_t *data, size_t size, long long *ts,
+			 enum video_colorspace cs, enum video_range_type range, struct obs_source_frame2 *frame,
+			 bool *got_output)
 {
 	int got_frame = false;
 	AVFrame *out_frame;
@@ -372,37 +345,32 @@ bool ffmpeg_decode_video(struct ffmpeg_decode *decode, uint8_t *data,
 	else if (!got_frame)
 		return true;
 
-#ifdef USE_NEW_HARDWARE_CODEC_METHOD
 	if (got_frame && decode->hw) {
 		ret = av_hwframe_transfer_data(decode->frame, out_frame, 0);
 		if (ret < 0) {
 			return false;
 		}
 	}
-#endif
 
 	for (size_t i = 0; i < MAX_AV_PLANES; i++) {
 		frame->data[i] = decode->frame->data[i];
 		frame->linesize[i] = decode->frame->linesize[i];
 	}
 
-	const enum video_format format =
-		convert_pixel_format(decode->frame->format);
+	const enum video_format format = convert_pixel_format(decode->frame->format);
 	frame->format = format;
 
 	if (range == VIDEO_RANGE_DEFAULT) {
-		range = (decode->frame->color_range == AVCOL_RANGE_JPEG)
-				? VIDEO_RANGE_FULL
-				: VIDEO_RANGE_PARTIAL;
+		range = (decode->frame->color_range == AVCOL_RANGE_JPEG) ? VIDEO_RANGE_FULL : VIDEO_RANGE_PARTIAL;
 	}
 
-	const enum video_colorspace cs = convert_color_space(
-		decode->frame->colorspace, decode->frame->color_trc,
-		decode->frame->color_primaries);
+	if (cs == VIDEO_CS_DEFAULT) {
+		cs = convert_color_space(decode->frame->colorspace, decode->frame->color_trc,
+					 decode->frame->color_primaries);
+	}
 
-	const bool success = video_format_get_parameters_for_format(
-		cs, range, format, frame->color_matrix, frame->color_range_min,
-		frame->color_range_max);
+	const bool success = video_format_get_parameters_for_format(cs, range, format, frame->color_matrix,
+								    frame->color_range_min, frame->color_range_max);
 	if (!success) {
 		blog(LOG_ERROR,
 		     "Failed to get video format "
